==> ogre-1.12_1.12.12.orig.tar.gz: ogre-1.12.12/RenderSystems/GLSupport/include/EGL/OgreEGLRenderTexture.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2008 Renato Araujo Oliveira Filho <renatox@gmail.com>
Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef __EGLRenderTexture_H__
#define __EGLRenderTexture_H__

#include "OgrePrerequisites.h"
#include "OgreGLPBuffer.h"
#include "OgreEGLContext.h"
#include "OgreEGLSupport.h"

namespace Ogre
{
    class GLContext;
    class EGLSupport;
    class EGLContext;

    class _OgrePrivate EGLPBuffer : public GLPBuffer
    {
        protected:
            EGLSupport*   mGLSupport;
            EGLContext*   mContext;
            ::EGLDisplay mGlDisplay;
            ::EGLSurface mEglDrawable;
        public:
            EGLPBuffer(EGLSupport* glsupport, PixelComponentType format, size_t width, size_t height);
            virtual ~EGLPBuffer();

            GLContext *getContext() const { return mContext; }
    };
}

#endif

==> ogre-13.0.1.tar.gz: ogre-13.0.1/RenderSystems/GLSupport/include/EGL/OgreEGLRenderTexture.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2008 Renato Araujo Oliveira Filho <renatox@gmail.com>
Copyright (c) 2000-2014 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/

#ifndef __EGLRenderTexture_H__
#define __EGLRenderTexture_H__

#include "OgrePrerequisites.h"
#include "OgreGLPBuffer.h"
#include "OgreEGLContext.h"
#include "OgreEGLSupport.h"

namespace Ogre
{
    class GLContext;
    class EGLSupport;
    class EGLContext;

    class _OgrePrivate EGLPBuffer : public GLPBuffer
    {
        protected:
            EGLSupport*   mGLSupport;
            EGLContext*   mContext;
            ::EGLDisplay mGlDisplay;
            ::EGLSurface mEglDrawable;
        public:
            EGLPBuffer(EGLSupport* glsupport, PixelComponentType format, uint32 width, uint32 height);
            virtual ~EGLPBuffer();

            GLContext *getContext() const { return mContext; }
    };
}

#endif
